==> percona-server-mongodb_4.0.27.orig.tar.gz: percona-server-mongodb-4.0.27-22/src/mongo/db/commands/feature_compatibility_version_command_parser.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>

#include "mongo/base/string_data.h"

namespace mongo {

class BSONObj;
template <typename T>
class StatusWith;

class FeatureCompatibilityVersionCommandParser {
public:
    static constexpr StringData kCommandName = "setFeatureCompatibilityVersion"_sd;

    /**
     * Interprets the specified BSON as a command and extracts the desired compatibility version
     * from it.
     */
    static StatusWith<std::string> extractVersionFromCommand(StringData commandName,
                                                             const BSONObj& cmdObj);
};

}  // namespace mongo

==> percona-server-mongodb-36_3.6.21.orig.tar.gz: percona-server-mongodb-3.6.21-10.0/src/mongo/db/commands/feature_compatibility_version_command_parser.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <string>

#include "mongo/base/string_data.h"

namespace mongo {

class BSONObj;
template <typename T>
class StatusWith;

namespace feature_compatibility_version {
constexpr StringData kDochubLink = "http://dochub.mongodb.org/core/3.6-feature-compatibility"_sd;
}  // namespace feature_compatibility_version

class FeatureCompatibilityVersionCommandParser {
public:
    /**
     * Known server release versions.
     */
    static constexpr StringData kVersion34 = "3.4"_sd;
    static constexpr StringData kVersionUpgradingTo36 = "upgrading to 3.6"_sd;
    static constexpr StringData kVersion36 = "3.6"_sd;
    static constexpr StringData kVersionDowngradingTo34 = "downgrading to 3.4"_sd;
    static constexpr StringData kVersionUnset = "Unset"_sd;

    /**
     * Interprets the specified BSON as a command and extracts the desired compatibility version
     * from it.
     */
    static StatusWith<std::string> extractVersionFromCommand(StringData commandName,
                                                             const BSONObj& cmdObj);
};

}  // namespace mongo
